#!/bin/sh

cd $(dirname $0)

cd deploy

# Start application in background
(
    # Execute all command needed to start the app. In this case we are exporting some variables and lauching a start.sh script inside deploy dir
    export USER=`busybox whoami`
    export HOME=`eval echo ~$USER`

    # Load kernel module on startup. This requires the application to be installed with "<executeAsRoot>true</executeAsRoot>"
    if ! modprobe tun; then
        logger -p error -t ixagent "Not able to load TUN/TAP device driver"
    fi

    if [ ! -f "/mnt/data/ixon/serial" ]; then
        get_serial_number=($(dbus-send --system --print-reply=literal --dest=com.exor.EPAD '/I2CSEEPROM' com.exor.EPAD.I2CSEEPROM.getSerialNumber))

        # The fifth element is our serial number between quotes.
        serial_number="${get_serial_number[5]}"

        # Strip the quotes.
        serial_number="${serial_number%\"}"
        serial_number="${serial_number#\"}"

        echo $serial_number > /mnt/data/ixon/serial
    fi

    ./start.sh $@;

    # If this point is reached it means the application is terminated. Notify to jmlauncher
    # The name "IXagent" should match the application name in the package.info <name> property
    # The function below is currently disabled because it will cause the whole device to reboot if the IXagent stops
    # dbus-send --print-reply --system --dest=com.exor.JMLauncher '/' com.exor.JMLauncher.appFinished string:"IXagent"
) &

sleep 1

# Store pid
PID=$(pgrep ixagent)
echo $PID > /var/run/ixagent.pid

# Wait until application is started
sleep 3

# Check that the application is running as expected. "IXagent" here is the name of the process, as shown in the ps command
if ( pgrep ixagent > /dev/null ); then
    # Notify the laucher the app has loaded.
    # The name "IXagent" should match the application name in the package.info <name> property
    dbus-send --print-reply --system --dest=com.exor.JMLauncher '/' com.exor.JMLauncher.appLoaded string:"IXagent"
fi


